const path = require('path');
const fs = require('fs');
const { name } = require('./package.json');
const icodeConfig = require('./icode.config.json');
module.exports = {
  layoutRoot: path.resolve(__dirname, 'src'),
  templatePath: path.resolve(__dirname, 'src/index.ejs'),
  publicPath: '/', // 子应用base路径
  outputPath: './dist', // 打包文件输出地址
  packEntry: {},
  isBundleAnalyzerPlugin: false,
  webpackConfig: (config, options) => {
    config.resolve.alias = {
      '@/utils/request': path.join(__dirname, 'src/utils/request.js'),
      '@/utils/myDva': path.join(__dirname, 'src/utils/myDva.js'),
      '@resources': path.join(__dirname, 'src/pages'),
      '@/layouts': path.join(__dirname, 'src/layouts'),
    };

    config.devServer.proxy = {
      ...(icodeConfig && icodeConfig.proxys || {})
    };

    config.plugins.push(
      new options.moduleFederationPlugin({
        name: name,
        filename: 'remoteEntry.js',
        library: { type: 'var', name: name },
        exposes: {},
        shared: {
          react: { singleton: true },
          'react-dom': { singleton: true },
        },
      })
    );

    const assetsPath = path.join(__dirname, 'assets');
    if (fs.existsSync(assetsPath)) {
      config.plugins.push(
        new options.CopyWebpackPlugin({
          patterns: [
            {
              from: assetsPath,
              to: 'assets',
            },
          ],
        }),
      );
    }

    return config;
  },
};
